Tutoriel
========

Ce tutoriel vous guide à travers la construction d'une API de catalogue de vin avec **Flask-Jeroboam**. Nous nous concentrons sur Jeroboam et supposons une certaine familiarité avec Flask. Si vous êtes nouveau à Flask, le `Tutoriel Flask <https://flask.palletsprojects.com/en/2.2.x/tutorial/>`_ est excellent.

.. _Flask Tutorial: https://flask.palletsprojects.com/en/2.2.x/tutorial/

.. toctree::
    :caption: Contenu :
    :maxdepth: 1

    setting_things_up_fr
    first_api_fr


Autres Ressources
-----------------

- Le `Méga Tutoriel <https://blog.miguelgrinberg.com/post/the-flask-mega-tutorial-part-i-hello-world>`_ de Michael Grinberg est une lecture incontournable. C'est une excellente introduction à Flask et il couvre beaucoup de terrain.
- La `Documentation FastAPI <https://fastapi.tiangolo.com/>`_ est à mon avis une référence en or. Elle est très bien écrite, complète et les exemples sont faciles à suivre. Vous devriez certainement la consulter. Elle a de la valeur même si vous n'allez pas utiliser FastAPI.
